@@ -1,7 +1,7 @@
 # ABSTRACT: Client to a {JSON:API} service (http://jsonapi.org/) v1.0
 package PONAPI::Client;
 
-our $VERSION = '0.002003';
+our $VERSION = '0.002004';
 
 use Moose;
 
@@ -43,72 +43,85 @@ has send_escape_values_header => (
     default => sub { 1 },
 );
 
+has 'uri_base' => (
+    is      => 'ro',
+    isa     => 'Maybe[Str]',
+    default => sub { '' },
+);
+
 
 ### public methods
 
 sub create {
-    my ( $self, @args ) = @_;
-    my $request = PONAPI::Client::Request::Create->new( @args );
+    my ($self)  = @_;
+    my $request = PONAPI::Client::Request::Create->new( _args(@_) );
     return $self->_send_ponapi_request( $request->request_params );
 }
 
 sub create_relationships {
-    my ( $self, @args ) = @_;
-    my $request = PONAPI::Client::Request::CreateRelationships->new( @args );
+    my ($self)  = @_;
+    my $request = PONAPI::Client::Request::CreateRelationships->new( _args(@_) );
     return $self->_send_ponapi_request( $request->request_params );
 }
 
 sub retrieve_all {
-    my ( $self, @args ) = @_;
-    my $request = PONAPI::Client::Request::RetrieveAll->new( @args );
+    my ($self)  = @_;
+    my $request = PONAPI::Client::Request::RetrieveAll->new( _args(@_) );
     return $self->_send_ponapi_request( $request->request_params );
 }
 
 sub retrieve {
-    my ( $self, @args ) = @_;
-    my $request = PONAPI::Client::Request::Retrieve->new( @args );
+    my ($self)  = @_;
+    my $request = PONAPI::Client::Request::Retrieve->new( _args(@_) );
     return $self->_send_ponapi_request( $request->request_params );
 }
 
 sub retrieve_relationships {
-    my ( $self, @args ) = @_;
-    my $request = PONAPI::Client::Request::RetrieveRelationships->new( @args );
+    my ($self)  = @_;
+    my $request = PONAPI::Client::Request::RetrieveRelationships->new( _args(@_) );
     return $self->_send_ponapi_request( $request->request_params );
 }
 
 sub retrieve_by_relationship {
-    my ( $self, @args ) = @_;
-    my $request = PONAPI::Client::Request::RetrieveByRelationship->new( @args );
+    my ($self)  = @_;
+    my $request = PONAPI::Client::Request::RetrieveByRelationship->new( _args(@_) );
     return $self->_send_ponapi_request( $request->request_params );
 }
 
 sub update {
-    my ( $self, @args ) = @_;
-    my $request = PONAPI::Client::Request::Update->new( @args );
+    my ($self)  = @_;
+    my $request = PONAPI::Client::Request::Update->new( _args(@_) );
     return $self->_send_ponapi_request( $request->request_params );
 }
 
 sub update_relationships {
-    my ( $self, @args ) = @_;
-    my $request = PONAPI::Client::Request::UpdateRelationships->new( @args );
+    my ($self)  = @_;
+    my $request = PONAPI::Client::Request::UpdateRelationships->new( _args(@_) );
     return $self->_send_ponapi_request( $request->request_params );
 }
 
 sub delete : method {
-    my ( $self, @args ) = @_;
-    my $request = PONAPI::Client::Request::Delete->new( @args );
+    my ($self)  = @_;
+    my $request = PONAPI::Client::Request::Delete->new( _args(@_) );
     return $self->_send_ponapi_request( $request->request_params );
 }
 
 sub delete_relationships {
-    my ( $self, @args ) = @_;
-    my $request = PONAPI::Client::Request::DeleteRelationships->new( @args );
+    my ($self)  = @_;
+    my $request = PONAPI::Client::Request::DeleteRelationships->new( _args(@_) );
     return $self->_send_ponapi_request( $request->request_params );
 }
 
 
 ### private methods
+
 use constant OLD_HIJK => $Hijk::VERSION lt '0.16';
+
+sub _args {
+    my $self = shift;
+    return ( @_, uri_base => $self->uri_base )
+}
+
 sub _send_ponapi_request {
     my $self = shift;
     my %args = @_;
@@ -176,7 +189,7 @@ PONAPI::Client - Client to a {JSON:API} service (http://jsonapi.org/) v1.0
 
 =head1 VERSION
 
-version 0.002003
+version 0.002004
 
 =head1 SYNOPSIS
 
@@ -262,6 +275,15 @@ version 0.002003
         ],
     );
 
+    # If the endpoint uses an uncommon url format:
+    $client->retrieve(
+        type => 'foo',
+        id   => 43,
+        # Will generate a request to
+        # host:port/type_foo_id_43
+        uri_template => "type_{type}_id_{id}",
+    );
+
 =head1 DESCRIPTION
 
 C<PONAPI::Client> is a L<{JSON:API}|http://jsonapi.org/> compliant client;
@@ -601,6 +623,83 @@ Adds to the specified one-to-many relationship.
 
 Deletes from the specified one-to-many relationship.
 
+=head1 Endpoint URI format
+
+By default, C<PONAPI::Client> assumes urls on the endpoint are in this format:
+
+    retrieve_all:               /$type
+    retrieve:                   /$type/$id
+    retrieve_by_relationships:  /$type/$id/$rel_type
+    retrieve_relationships:     /$type/$id/relationships/$rel_type
+
+    create:                     /$type or /$type/$id
+    delete:                     /$type/$id
+    update:                     /$type/$id
+
+    update_relationships:       /$type/$id/relationships/$rel_type
+    create_relationships:       /$type/$id/relationships/$rel_type
+    delete_relationships:       /$type/$id/relationships/$rel_type
+
+    # Will generate a request to /foo/99
+    $client->retrieve(
+        type => 'foo',
+        id   => 99,
+    );
+
+However, if another format is needed, two approaches are possible:
+
+=head2 URI paths have a common prefix
+
+If all the endpoint urls have a common prefix, ala C</v1/articles>
+instead of simply C</articles>, then you can just set C<uri_base>
+as needed:
+
+    $client->retrieve(
+        type     => 'foo',
+        id       => 99,
+        uri_base => '/v1'
+    );
+
+We can also set this when creating the client; if done this way,
+all requests generated from this client will include the base:
+
+    my $new_client = PONAPI::Client->new(
+        uri_base => '/v1',
+        ...
+    );
+
+    # This will generate a request to /v1/foo/99
+    $new_client->retrieve(
+        type => 'foo',
+        id   => 99,
+    );
+
+=head2 Completely different uris
+
+If the endpoint's expected formats are wildly different, you can specify
+C<uri_template> with your request:
+
+    # Will generate a request to id_here_99_and_type_there/foo
+    $client->retrieve(
+        type => 'foo',
+        id   => 99,
+        uri_template => 'id_here_{id}_and_type_there/{type}'
+    );
+
+These placeholders are recognized:
+
+=over 4
+
+=item * type
+
+=item * id
+
+=item * rel_type
+
+=back
+
+This can only be done on a per-request basis.
+
 =head1 AUTHORS
 
 =over 4
