@@ -3,6 +3,7 @@ package PONAPI::Client::Request;
 
 use Moose::Role;
 
+use URI::Template;
 use JSON::XS qw< encode_json >;
 
 use PONAPI::Utils::URI qw< to_uri >;
@@ -10,14 +11,31 @@ use PONAPI::Utils::URI qw< to_uri >;
 requires 'method';
 requires 'path';
 
+has 'uri_base' => (
+    is      => 'ro',
+    isa     => 'Maybe[Str]',
+    default => sub { '' },
+);
+
+sub BUILDARGS {
+    my $class = shift;
+    my %args = @_ == 1 ? %{ $_[0] } : @_;
+    $args{uri_base} =~ s|/$||
+        if exists $args{uri_base} and defined $args{uri_base};
+    return \%args;
+}
+
 sub request_params {
     my $self = shift;
 
     my $method = $self->method;
 
+    my $template = URI::Template->new( $self->uri_template );
+    my $path     = $template->process( %{ $self->path } )->path;
+
     return (
         method => $method,
-        path   => $self->path,
+        path   => $self->uri_base . $path,
         ( $method eq 'GET'
             ? ( query_string => $self->_build_query_string )
             : ( $self->can('data')
@@ -65,7 +83,7 @@ PONAPI::Client::Request - request class
 
 =head1 VERSION
 
-version 0.002003
+version 0.002004
 
 =head1 AUTHORS
 
