@@ -6,12 +6,8 @@ use Moose;
 with 'PONAPI::Client::Request',
      'PONAPI::Client::Request::Role::IsPOST',
      'PONAPI::Client::Request::Role::HasType',
-     'PONAPI::Client::Request::Role::HasData';
-
-sub path   {
-    my $self = shift;
-    return '/' . $self->type;
-}
+     'PONAPI::Client::Request::Role::HasData',
+     'PONAPI::Client::Request::Role::HasUriAll';
 
 __PACKAGE__->meta->make_immutable;
 no Moose; 1;
@@ -28,7 +24,7 @@ PONAPI::Client::Request::Create - request - create
 
 =head1 VERSION
 
-version 0.002003
+version 0.002004
 
 =head1 AUTHORS
 
