@@ -8,12 +8,8 @@ with 'PONAPI::Client::Request',
      'PONAPI::Client::Request::Role::HasType',
      'PONAPI::Client::Request::Role::HasId',
      'PONAPI::Client::Request::Role::HasRelationshipType',
-     'PONAPI::Client::Request::Role::HasOneToManyData';
-
-sub path   {
-    my $self = shift;
-    return '/' . $self->type . '/' . $self->id . '/relationships/' . $self->rel_type;
-}
+     'PONAPI::Client::Request::Role::HasOneToManyData',
+     'PONAPI::Client::Request::Role::HasUriRelationships';
 
 __PACKAGE__->meta->make_immutable;
 no Moose; 1;
@@ -30,7 +26,7 @@ PONAPI::Client::Request::CreateRelationships - request - create relationships
 
 =head1 VERSION
 
-version 0.002003
+version 0.002004
 
 =head1 AUTHORS
 
