@@ -6,12 +6,8 @@ use Moose;
 with 'PONAPI::Client::Request',
      'PONAPI::Client::Request::Role::IsDELETE',
      'PONAPI::Client::Request::Role::HasType',
-     'PONAPI::Client::Request::Role::HasId';
-
-sub path   {
-    my $self = shift;
-    return '/' . $self->type . '/' . $self->id;
-}
+     'PONAPI::Client::Request::Role::HasId',
+     'PONAPI::Client::Request::Role::HasUriSingle';
 
 __PACKAGE__->meta->make_immutable;
 no Moose; 1;
@@ -28,7 +24,7 @@ PONAPI::Client::Request::Delete - request - delete
 
 =head1 VERSION
 
-version 0.002003
+version 0.002004
 
 =head1 AUTHORS
 
