@@ -10,12 +10,8 @@ with 'PONAPI::Client::Request',
      'PONAPI::Client::Request::Role::HasFilter',
      'PONAPI::Client::Request::Role::HasInclude',
      'PONAPI::Client::Request::Role::HasPage',
-     'PONAPI::Client::Request::Role::HasSort';
-
-sub path   {
-    my $self = shift;
-    return '/' . $self->type;
-}
+     'PONAPI::Client::Request::Role::HasSort',
+     'PONAPI::Client::Request::Role::HasUriAll';
 
 __PACKAGE__->meta->make_immutable;
 no Moose; 1;
@@ -32,7 +28,7 @@ PONAPI::Client::Request::RetrieveAll - request - retrieve all
 
 =head1 VERSION
 
-version 0.002003
+version 0.002004
 
 =head1 AUTHORS
 
