@@ -9,12 +9,8 @@ with 'PONAPI::Client::Request',
      'PONAPI::Client::Request::Role::HasId',
      'PONAPI::Client::Request::Role::HasRelationshipType',
      'PONAPI::Client::Request::Role::HasFilter',
-     'PONAPI::Client::Request::Role::HasPage';
-
-sub path   {
-    my $self = shift;
-    return '/' . $self->type . '/' . $self->id .'/relationships/' . $self->rel_type;
-}
+     'PONAPI::Client::Request::Role::HasPage',
+     'PONAPI::Client::Request::Role::HasUriRelationships';
 
 __PACKAGE__->meta->make_immutable;
 no Moose; 1;
@@ -31,7 +27,7 @@ PONAPI::Client::Request::RetrieveRelationships - request - retrieve relationship
 
 =head1 VERSION
 
-version 0.002003
+version 0.002004
 
 =head1 AUTHORS
 
