@@ -7,12 +7,8 @@ with 'PONAPI::Client::Request',
      'PONAPI::Client::Request::Role::IsPATCH',
      'PONAPI::Client::Request::Role::HasType',
      'PONAPI::Client::Request::Role::HasId',
-     'PONAPI::Client::Request::Role::HasData';
-
-sub path   {
-    my $self = shift;
-    return '/' . $self->type . '/' . $self->id;
-}
+     'PONAPI::Client::Request::Role::HasData',
+     'PONAPI::Client::Request::Role::HasUriSingle';
 
 __PACKAGE__->meta->make_immutable;
 no Moose; 1;
@@ -29,7 +25,7 @@ PONAPI::Client::Request::Update - request - update
 
 =head1 VERSION
 
-version 0.002003
+version 0.002004
 
 =head1 AUTHORS
 
